@@ -49,7 +49,6 @@
 #include "gyahtzee.h"
 #include "games-scores.h"
 #include "games-scores-dialog.h"
-#include "games-stock.h"
 
 #define DELAY_MS 600
 
@@ -59,9 +58,9 @@ static guint last_timeout = 0;
 static gboolean ready_to_advance_player;
 
 #define NUMBER_OF_PIXMAPS    7
-#define GAME_TYPES 2
+#define GAME_TYPES           2
 #define DIE_SELECTED_PIXMAP  (NUMBER_OF_PIXMAPS-1)
-#define SCORES_CATEGORY (game_type == GAME_KISMET ? "Colors" : NULL)
+#define SCORES_CATEGORY      (game_type == GAME_KISMET ? "Colors" : NULL)
 
 static char *dicefiles[NUMBER_OF_PIXMAPS] = { "gnome-dice-1.svg",
   "gnome-dice-2.svg",
@@ -123,7 +122,7 @@ GamesScores *highscores;
 
 static GtkWidget *dialog = NULL;
 
-static gint modify_dice (GtkWidget * widget, gpointer data);
+static void modify_dice (GtkToolButton * widget, gpointer data);
 static void UpdateRollLabel (void);
 
 static void
@@ -136,7 +135,7 @@ update_roll_button_sensitivity (void)
     state |=
       gtk_toggle_tool_button_get_active (GTK_TOGGLE_TOOL_BUTTON (diceBox[i]));
 
-  if(!state){
+  if (!state) {
     gtk_button_set_label (GTK_BUTTON (mbutton), _("Roll all!"));
     state = TRUE;
   } else {
@@ -147,7 +146,7 @@ update_roll_button_sensitivity (void)
   state &= NumberOfRolls < 3;
   state &= !players[CurrentPlayer].comp;
 
-  if(GameIsOver ()){
+  if (GameIsOver ()) {
     state = FALSE;
   }
 
@@ -246,7 +245,7 @@ do_computer_turns (void)
 /* Show the current score and prompt for current player state */
 
 void
-DisplayCurrentPlayer(void) {
+DisplayCurrentPlayer (void) {
   ShowoffPlayer (ScoreList, CurrentPlayer, 1);
 
   if (players[CurrentPlayer].name) {
@@ -260,11 +259,11 @@ DisplayCurrentPlayer(void) {
 
 /* Display current player and refresh dice/display */
 void
-DisplayCurrentPlayerRefreshDice(void) {
-  DisplayCurrentPlayer();
+DisplayCurrentPlayerRefreshDice (void) {
+  DisplayCurrentPlayer ();
   UpdateAllDicePixmaps ();
   DeselectAllDice ();
-  UpdateRollLabel();
+  UpdateRollLabel ();
 }
 
 void
@@ -279,8 +278,8 @@ NextPlayer (void)
         NumberOfRolls = NUM_ROLLS;
     else
         NumberOfRolls = LastHumanNumberOfRolls;
-    /* update_roll_button_sensitivity() needs to be called in
-       this context however UpdateRollLabel() also calls that method */
+    /* update_roll_button_sensitivity () needs to be called in
+       this context however UpdateRollLabel () also calls that method */
     UpdateRollLabel ();
     CheerWinner ();
     return;
@@ -295,10 +294,10 @@ NextPlayer (void)
     CurrentPlayer = (CurrentPlayer + 1) % NumberOfPlayers;
   } while (players[CurrentPlayer].finished);
 
-  DisplayCurrentPlayer();
+  DisplayCurrentPlayer ();
   SelectAllDice ();
   RollSelectedDice ();
-  FreeRedoList();
+  FreeRedoList ();
 
   /* Remember the roll count if this turn is for a
      human player for display at the end of the game */
@@ -323,41 +322,41 @@ NextPlayer (void)
 /* Go back to the previous player */
 
 void
-PreviousPlayer(void)
+PreviousPlayer (void)
 {
-  if (UndoPossible()) {
+  if (UndoPossible ()) {
     NumberOfRolls = 1;
     ready_to_advance_player = FALSE;
     ShowoffPlayer (ScoreList, CurrentPlayer, 0);
 
     /* Find the next player with rolls left */
     do {
-      CurrentPlayer = (UndoLastMove() + NumberOfPlayers) % NumberOfPlayers;
-    } while (players[CurrentPlayer].comp && UndoPossible());
+      CurrentPlayer = (UndoLastMove () + NumberOfPlayers) % NumberOfPlayers;
+    } while (players[CurrentPlayer].comp && UndoPossible ());
 
-    DisplayCurrentPlayerRefreshDice();
+    DisplayCurrentPlayerRefreshDice ();
   }
 }
 
 void
-RedoPlayer(void)
+RedoPlayer (void)
 {
-  if (RedoPossible()) {
+  if (RedoPossible ()) {
     NumberOfRolls = 1;
     ready_to_advance_player = FALSE;
-    ShowoffPlayer(ScoreList, CurrentPlayer, 0);
+    ShowoffPlayer (ScoreList, CurrentPlayer, 0);
     /* The first element of the list is the undone turn, so
      * we need to remove it from the list before redoing other
      * turns.                                                    */
-    FreeRedoListHead();
+    FreeRedoListHead ();
 
     /* Redo all computer players */
     do {
-      CurrentPlayer = RedoLastMove();
-    } while (players[CurrentPlayer].comp && RedoPossible());
+      CurrentPlayer = RedoLastMove ();
+    } while (players[CurrentPlayer].comp && RedoPossible ());
 
-    RestoreLastRoll();
-    DisplayCurrentPlayerRefreshDice();
+    RestoreLastRoll ();
+    DisplayCurrentPlayerRefreshDice ();
   }
 }
 
@@ -448,8 +447,8 @@ GyahtzeeNewGame (void)
 
   say (_("Select dice to roll or choose a score slot."));
 
-  game_type = get_new_game_type();
-  games_scores_set_category(highscores, SCORES_CATEGORY);
+  game_type = get_new_game_type ();
+  games_scores_set_category (highscores, SCORES_CATEGORY);
   NewGame ();
   setup_score_list (ScoreList);
   UpdateRollLabel ();
@@ -518,8 +517,8 @@ DeselectAllDice (void)
 }
 
 /* Callback on dice press */
-gint
-modify_dice (GtkWidget * widget, gpointer data)
+static void
+modify_dice (GtkToolButton * widget, gpointer data)
 {
   DiceInfo *tmp = (DiceInfo *) data;
   GtkToggleToolButton *button = GTK_TOGGLE_TOOL_BUTTON (widget);
@@ -528,13 +527,13 @@ modify_dice (GtkWidget * widget, gpointer data)
   if (players[CurrentPlayer].finished || players[CurrentPlayer].comp) {
     if (gtk_toggle_tool_button_get_active (button))
       gtk_toggle_tool_button_set_active (button, FALSE);
-    return TRUE;
+    return;
   }
 
   if (NumberOfRolls >= NUM_ROLLS) {
     say (_("You are only allowed three rolls. Choose a score slot."));
     gtk_toggle_tool_button_set_active (button, FALSE);
-    return TRUE;
+    return;
   }
 
   tmp->sel = gtk_toggle_tool_button_get_active (button);
@@ -542,23 +541,33 @@ modify_dice (GtkWidget * widget, gpointer data)
   UpdateAllDicePixmaps ();
 
   update_roll_button_sensitivity ();
-  return TRUE;
+  return;
 }
 
-
-/* Callback on Roll! button press */
 static void
-roll_cb (GSimpleAction * action, GVariant * parameter, gpointer data)
+roll (void)
 {
   if (!players[CurrentPlayer].comp) {
     RollSelectedDice ();
     if (NumberOfRolls > 1)
-        FreeUndoRedoLists();
+        FreeUndoRedoLists ();
     UpdateRollLabel ();
     LastHumanNumberOfRolls = NumberOfRolls;
   }
 }
 
+static void
+roll_button_pressed_cb (GtkButton * button, gpointer data)
+{
+  roll ();
+}
+
+static void
+roll_cb (GSimpleAction * action, GVariant * parameter, gpointer data)
+{
+  roll ();
+}
+
 void
 say (char *fmt, ...)
 {
@@ -603,8 +612,7 @@ about_cb (GSimpleAction * action, GVariant * parameter, gpointer data)
 			 "Free Software Foundation, Inc.",
 			 "license-type", GTK_LICENSE_GPL_2_0,
 			 "comments", _("A variation on poker with "
-				       "dice and less money\n\n"
-				       "Tali is a part of GNOME Games."),
+				       "dice and less money."),
 			 "authors", authors,
 			 "documenters", documenters,
 			 "translator-credits", _("translator-credits"),
@@ -633,7 +641,7 @@ score_cb (GSimpleAction * action, GVariant * parameter, gpointer data)
 static void
 undo_cb (GSimpleAction * action, GVariant * parameter, gpointer data)
 {
-  PreviousPlayer();
+  PreviousPlayer ();
 }
 
 static void
@@ -674,8 +682,8 @@ LoadDicePixmaps (void)
       }
 
     } /* FIXME: What happens if the file isn't found. */
-    g_free(path);
-    g_free(path_kismet);
+    g_free (path);
+    g_free (path_kismet);
   }
 }
 
@@ -709,7 +717,7 @@ static const GActionEntry app_entries[] = {
 
 
 static void
-GyahtzeeCreateMainWindow (void)
+GyahtzeeCreateMainWindow (GApplication *app, gpointer user_data)
 {
   GtkWidget *hbox, *vbox;
   GtkWidget *toolbar;
@@ -723,11 +731,11 @@ GyahtzeeCreateMainWindow (void)
   gtk_window_set_application (GTK_WINDOW (window), application);
   gtk_window_set_title (GTK_WINDOW (window), _(appName));
   gtk_window_set_hide_titlebar_when_maximized (GTK_WINDOW (window), FALSE);
-  gtk_window_set_icon_name(GTK_WINDOW (window), "tali");
+  gtk_window_set_icon_name (GTK_WINDOW (window), "tali");
 
   //games_conf_add_window (GTK_WINDOW (window), NULL);
 
-  g_signal_connect (G_OBJECT (window), "key_press_event",
+  g_signal_connect (GTK_WIDGET (window), "key_press_event",
 		    G_CALLBACK (key_press), NULL);
 
   g_action_map_add_action_entries (G_ACTION_MAP (application), app_entries, G_N_ELEMENTS (app_entries), application);
@@ -736,7 +744,7 @@ GyahtzeeCreateMainWindow (void)
   gtk_application_add_accelerator (application, "<Primary>r", "app.roll", NULL);
   gtk_application_add_accelerator (application, "F1", "app.help", NULL);
 
-	/*---- Menus ----*/
+  /*---- Menus ----*/
   app_menu = g_menu_new ();
   section = g_menu_new ();
   g_menu_append_section (app_menu, NULL, G_MENU_MODEL (section));
@@ -750,7 +758,7 @@ GyahtzeeCreateMainWindow (void)
   g_menu_append (section, _("_Quit"), "app.quit");
   scores_action = g_action_map_lookup_action (G_ACTION_MAP (application), "scores");
   undo_action   = g_action_map_lookup_action (G_ACTION_MAP (application), "undo");
-  update_undo_sensitivity();
+  update_undo_sensitivity ();
   gtk_application_set_app_menu (GTK_APPLICATION (application), G_MENU_MODEL (app_menu));
 
         /*--- Headerbar ---*/
@@ -794,8 +802,8 @@ GyahtzeeCreateMainWindow (void)
 
   mbutton = gtk_button_new_with_label (_("Roll!"));
   gtk_box_pack_end (GTK_BOX (dicebox), mbutton, FALSE, FALSE, 5);
-  g_signal_connect (G_OBJECT (mbutton), "clicked",
-		    G_CALLBACK (roll_cb), NULL);
+  g_signal_connect (GTK_BUTTON (mbutton), "clicked",
+		    G_CALLBACK (roll_button_pressed_cb), NULL);
   gtk_widget_show (GTK_WIDGET (mbutton));
 
   toolbar = gtk_toolbar_new ();
@@ -815,7 +823,7 @@ GyahtzeeCreateMainWindow (void)
 
     diceBox[i] = gtk_toggle_tool_button_new ();
     gtk_tool_button_set_icon_widget (GTK_TOOL_BUTTON (diceBox[i]), tmp);
-    g_signal_connect (G_OBJECT (diceBox[i]), "clicked",
+    g_signal_connect (GTK_TOOL_BUTTON (diceBox[i]), "clicked",
 		      G_CALLBACK (modify_dice), &DiceValues[i]);
 
     gtk_toolbar_insert (GTK_TOOLBAR (toolbar),
@@ -835,10 +843,15 @@ GyahtzeeCreateMainWindow (void)
 
   gtk_widget_show (hbox);
   gtk_widget_show (vbox);
+}
 
-  gtk_widget_show (window);
-
-  GyahtzeeNewGame ();
+static void
+GyahtzeeActivateGame (GApplication *app, gpointer user_data)
+{
+  if (!gtk_widget_is_visible (window)) {
+    gtk_widget_show (window);
+    GyahtzeeNewGame ();
+  }
 }
 
 int
@@ -857,7 +870,8 @@ main (int argc, char *argv[])
   textdomain (GETTEXT_PACKAGE);
 
   application = gtk_application_new ("org.gnome.tali", 0);
-  g_signal_connect (application, "activate", G_CALLBACK (GyahtzeeCreateMainWindow), NULL);
+  g_signal_connect (application, "startup", G_CALLBACK (GyahtzeeCreateMainWindow), NULL);
+  g_signal_connect (application, "activate", G_CALLBACK (GyahtzeeActivateGame), NULL);
 
   games_scores_startup ();
 
@@ -880,23 +894,21 @@ main (int argc, char *argv[])
 
   g_set_application_name (_(appName));
 
-  games_stock_init ();
-
   /* If we're in computer test mode, just run some tests, no GUI */
   if (test_computer_play > 0) {
       gint ii, jj, kk;
       gdouble sum_scores = 0.0;
       game_type = GAME_YAHTZEE;
       if (game_type_string)
-          game_type = game_type_from_string(game_type_string);
-      g_message("In test computer play section - Using %d trials for simulation", NUM_TRIALS);
+          game_type = game_type_from_string (game_type_string);
+      g_message ("In test computer play section - Using %d trials for simulation", NUM_TRIALS);
       for (ii = 0; ii < test_computer_play; ii++) {
           int num_rolls = 0;
           NumberOfHumans = 0;
           NumberOfComputers = 1;
           NewGame ();
 
-          while (!GameIsOver() && num_rolls < 100) {
+          while (!GameIsOver () && num_rolls < 100) {
               ComputerRolling (CurrentPlayer);
               if (NoDiceSelected () || (NumberOfRolls >= NUM_ROLLS)) {
                 ComputerScoring (CurrentPlayer);
@@ -909,16 +921,16 @@ main (int argc, char *argv[])
               num_rolls++;
           }
           for (kk = NumberOfHumans; kk < NumberOfPlayers; kk++) {
-              printf("Computer score: %d\n", total_score(kk));
-              sum_scores += total_score(kk);
+              printf ("Computer score: %d\n", total_score (kk));
+              sum_scores += total_score (kk);
               if (num_rolls > 98) {
                   for (jj = 0; jj < NUM_FIELDS; jj++)
-                      g_message("Category %d is score %d", jj, players[kk].score[jj]);
+                      g_message ("Category %d is score %d", jj, players[kk].score[jj]);
               }
           }
       }
-      printf("Computer average: %.2f for %d trials\n", sum_scores / test_computer_play, NUM_TRIALS);
-      exit(0);
+      printf ("Computer average: %.2f for %d trials\n", sum_scores / test_computer_play, NUM_TRIALS);
+      exit (0);
   }
 
   highscores = games_scores_new ("tali",
@@ -946,15 +958,15 @@ main (int argc, char *argv[])
     NumberOfComputers = MAX_NUMBER_OF_PLAYERS - NumberOfHumans;
 
   if (game_type_string)
-    game_type = game_type_from_string(game_type_string);
+    game_type = game_type_from_string (game_type_string);
   else {
     char *type;
 
     type = g_settings_get_string (settings, "game-type");
-    game_type = game_type_from_string(type);
+    game_type = game_type_from_string (type);
   }
 
-  set_new_game_type(game_type);
+  set_new_game_type (game_type);
 
   if (NUM_TRIALS <= 0)
       NUM_TRIALS = g_settings_get_int (settings, "monte-carlo-trials");
@@ -991,7 +1003,7 @@ main (int argc, char *argv[])
 
   g_application_run (G_APPLICATION (application), argc, argv);
 
-  exit(0);
+  exit (0);
 }
 
 /* Arrgh - lets all use the same tabs under emacs: 
